Churn in a TV subscription company

This is a private dataset provided by a TV cable provider.
The dataset consists of active customers during the first semester of 2014.
The total dataset contains 9,410 individual registries, each one with 45 attributes,
including a churn label indicating whenever a customer is a churner.
This label was created internally in the company, and can be regarded as highly accurate.
In the dataset only 455 customers are churners, leading to a churn ratio of 4.83 %.

The features names are anonymized to protect the privacy of the customers.

=================   ==============
Classes                          2
Churners                       455
Non-churners                  8955
Samples                       9410
Features                        45
=================   ==============

For more information, read the User Guide https://empulse.readthedocs.io/en/latest/guide/datasets_guide.html
